@@ -1,8 +1,10 @@
+from typing import Callable
+
 from ..filters import Filters
 
 
 class Handler:
-    def __init__(self, callback: callable, filters: Filters = None):
+    def __init__(self, callback: Callable, filters: Filters = None):
         self.callback = callback
         self.filters = filters
 
