@@ -1,9 +1,10 @@
 import trio
 
 from chameleongram.exceptions import Propagate, NowStop
+from ..base import Base
 
 
-class Run:
+class Run(Base):
     async def run(self):
         """Run a client instance."""
 
@@ -11,7 +12,10 @@ class Run:
 
         while True:
             if self.handlers:
-                update = await self.recv()
+                try:
+                    update = await self.recv()
+                except AttributeError:
+                    break
 
                 for handler in self.handlers:
                     _update = update
