@@ -42,7 +42,8 @@ _all = {
     0x7ae43737: functions.account.InstallTheme,
     0xfeed5769: functions.account.InstallWallPaper,
     0x68976c6f: functions.account.RegisterDevice,
-    0xae189d5f: functions.account.ReportPeer,
+    0xc5ba3d86: functions.account.ReportPeer,
+    0xfa8cc6f5: functions.account.ReportProfilePhoto,
     0x7a7f2a15: functions.account.ResendPasswordEmail,
     0xdf77f3bc: functions.account.ResetAuthorization,
     0xdb7e1747: functions.account.ResetNotifySettings,
@@ -96,6 +97,7 @@ _all = {
     0xaa2769ed: functions.bots.SendCustomRequest,
     0x805d46f6: functions.bots.SetBotCommands,
     0x10e6bd2c: functions.channels.CheckUsername,
+    0xb290c69: functions.channels.ConvertToGigagroup,
     0x3d5fb10f: functions.channels.CreateChannel,
     0xc0111fe3: functions.channels.DeleteChannel,
     0xaf369d42: functions.channels.DeleteHistory,
@@ -153,7 +155,7 @@ _all = {
     0x1c295881: functions.folders.DeleteFolder,
     0x6847d0ab: functions.folders.EditPeerFolders,
     0xee72f79a: functions.help.AcceptTermsOfService,
-    0x77fa99f: functions.help.DismissSuggestion,
+    0xf50dbaa1: functions.help.DismissSuggestion,
     0x66b91b70: functions.help.EditUserInfo,
     0x9010ef6f: functions.help.GetAppChangelog,
     0x98914110: functions.help.GetAppConfig,
@@ -190,30 +192,38 @@ _all = {
     0xf729ea98: functions.messages.AcceptUrlAuth,
     0xf9a0aa09: functions.messages.AddChatUser,
     0x3eadb1bb: functions.messages.CheckChatInvite,
+    0x43fe19f3: functions.messages.CheckHistoryImport,
     0x7e58ee9c: functions.messages.ClearAllDrafts,
     0x8999602d: functions.messages.ClearRecentStickers,
     0x9cb126e: functions.messages.CreateChat,
-    0xe0611f16: functions.messages.DeleteChatUser,
+    0x83247d11: functions.messages.DeleteChat,
+    0xc534459a: functions.messages.DeleteChatUser,
+    0xd464a42b: functions.messages.DeleteExportedChatInvite,
     0x1c015b09: functions.messages.DeleteHistory,
     0xe58e95d2: functions.messages.DeleteMessages,
+    0xf9cbe409: functions.messages.DeletePhoneCallHistory,
+    0x56987bd5: functions.messages.DeleteRevokedExportedChatInvites,
     0x59ae2b16: functions.messages.DeleteScheduledMessages,
-    0xedd923c5: functions.messages.DiscardEncryption,
+    0xf393aea0: functions.messages.DiscardEncryption,
     0xdef60797: functions.messages.EditChatAbout,
     0xa9e69f2e: functions.messages.EditChatAdmin,
     0xa5866b41: functions.messages.EditChatDefaultBannedRights,
     0xca4c79d8: functions.messages.EditChatPhoto,
     0xdc452855: functions.messages.EditChatTitle,
+    0x2e4ffbe: functions.messages.EditExportedChatInvite,
     0x83557dba: functions.messages.EditInlineBotMessage,
     0x48f71778: functions.messages.EditMessage,
-    0xdf7534c: functions.messages.ExportChatInvite,
+    0x14b9bcd7: functions.messages.ExportChatInvite,
     0xb9ffc55b: functions.messages.FaveSticker,
     0xd9fee60e: functions.messages.ForwardMessages,
+    0x3920e6ef: functions.messages.GetAdminsWithInvites,
     0xeba80ff0: functions.messages.GetAllChats,
     0x6a3f8d65: functions.messages.GetAllDrafts,
     0x1c9618b1: functions.messages.GetAllStickers,
     0x57f17692: functions.messages.GetArchivedStickers,
     0xcc5b67cc: functions.messages.GetAttachedStickers,
     0x9342ca07: functions.messages.GetBotCallbackAnswer,
+    0x26fb7289: functions.messages.GetChatInviteImporters,
     0x3c6aa187: functions.messages.GetChats,
     0xd0a48c4: functions.messages.GetCommonChats,
     0x26cf8950: functions.messages.GetDhConfig,
@@ -226,6 +236,7 @@ _all = {
     0x1508b6af: functions.messages.GetEmojiKeywordsDifference,
     0x4e9963b2: functions.messages.GetEmojiKeywordsLanguages,
     0xd5b10c26: functions.messages.GetEmojiURL,
+    0xa2b5a3f6: functions.messages.GetExportedChatInvites,
     0x21ce0b0e: functions.messages.GetFavedStickers,
     0x2dacca4f: functions.messages.GetFeaturedStickers,
     0x3b831c66: functions.messages.GetFullChat,
@@ -261,6 +272,7 @@ _all = {
     0x8b68b0cc: functions.messages.GetWebPagePreview,
     0x4facb138: functions.messages.HidePeerSettingsBar,
     0x6c50051c: functions.messages.ImportChatInvite,
+    0x34090c3b: functions.messages.InitHistoryImport,
     0xc78fe460: functions.messages.InstallStickerSet,
     0xc286d98f: functions.messages.MarkDialogUnread,
     0x15a3b8e3: functions.messages.MigrateChat,
@@ -274,7 +286,7 @@ _all = {
     0x55a5bb66: functions.messages.ReceivedQueue,
     0x3b1adf37: functions.messages.ReorderPinnedDialogs,
     0x78337739: functions.messages.ReorderStickerSets,
-    0xbd82b658: functions.messages.Report,
+    0x8953ab4e: functions.messages.Report,
     0x4b0c8c0f: functions.messages.ReportEncryptedSpam,
     0xcf1592db: functions.messages.ReportSpam,
     0xf64daf43: functions.messages.RequestEncryption,
@@ -300,10 +312,12 @@ _all = {
     0xe5f672fa: functions.messages.SetBotShippingResults,
     0x791451ed: functions.messages.SetEncryptedTyping,
     0x8ef8ecc0: functions.messages.SetGameScore,
+    0xb80e5fe4: functions.messages.SetHistoryTTL,
     0xeb5ea206: functions.messages.SetInlineBotResults,
     0x15ad9f64: functions.messages.SetInlineGameScore,
     0x58943ee2: functions.messages.SetTyping,
     0xe6df7378: functions.messages.StartBot,
+    0xb43df344: functions.messages.StartHistoryImport,
     0xa731e257: functions.messages.ToggleDialogPin,
     0xb5052fea: functions.messages.ToggleStickerSets,
     0xf96e55de: functions.messages.UninstallStickerSet,
@@ -312,6 +326,7 @@ _all = {
     0xc563c1e4: functions.messages.UpdateDialogFiltersOrder,
     0xd2aaf7ec: functions.messages.UpdatePinnedMessage,
     0x5057c497: functions.messages.UploadEncryptedFile,
+    0x2a862092: functions.messages.UploadImportedMedia,
     0x519bc2b1: functions.messages.UploadMedia,
     0xd83d70c1: functions.payments.ClearSavedInfo,
     0x2e79d779: functions.payments.GetBankCardData,
@@ -326,7 +341,7 @@ _all = {
     0xbd3dabe0: functions.phone.CreateGroupCall,
     0xb2cbc1c0: functions.phone.DiscardCall,
     0x7a777135: functions.phone.DiscardGroupCall,
-    0x63146ae4: functions.phone.EditGroupCallMember,
+    0xa5e76cd8: functions.phone.EditGroupCallMember,
     0x55451fa9: functions.phone.GetCallConfig,
     0xc7cb017: functions.phone.GetGroupCall,
     0xc9f1d285: functions.phone.GetGroupParticipants,
@@ -421,6 +436,7 @@ _all = {
     0xd31a961e: types.Channel,
     0x3b5a3e40: types.ChannelAdminLogEvent,
     0x55188a2e: types.ChannelAdminLogEventActionChangeAbout,
+    0x6e941a38: types.ChannelAdminLogEventActionChangeHistoryTTL,
     0xa26f881b: types.ChannelAdminLogEventActionChangeLinkedChat,
     0xe6b76ae: types.ChannelAdminLogEventActionChangeLocation,
     0x434bd2af: types.ChannelAdminLogEventActionChangePhoto,
@@ -431,13 +447,18 @@ _all = {
     0x42e047bb: types.ChannelAdminLogEventActionDeleteMessage,
     0xdb9f9140: types.ChannelAdminLogEventActionDiscardGroupCall,
     0x709b2405: types.ChannelAdminLogEventActionEditMessage,
+    0x5a50fca4: types.ChannelAdminLogEventActionExportedInviteDelete,
+    0xe90ebb59: types.ChannelAdminLogEventActionExportedInviteEdit,
+    0x410a134e: types.ChannelAdminLogEventActionExportedInviteRevoke,
     0xe31c34d8: types.ChannelAdminLogEventActionParticipantInvite,
     0x183040d3: types.ChannelAdminLogEventActionParticipantJoin,
+    0x5cdada77: types.ChannelAdminLogEventActionParticipantJoinByInvite,
     0xf89777f2: types.ChannelAdminLogEventActionParticipantLeave,
     0xf92424d2: types.ChannelAdminLogEventActionParticipantMute,
     0xd5676710: types.ChannelAdminLogEventActionParticipantToggleAdmin,
     0xe6d83d7e: types.ChannelAdminLogEventActionParticipantToggleBan,
     0xe64429c0: types.ChannelAdminLogEventActionParticipantUnmute,
+    0x3e7f6847: types.ChannelAdminLogEventActionParticipantVolume,
     0x23209745: types.ChannelAdminLogEventActionStartGroupCall,
     0x8f079643: types.ChannelAdminLogEventActionStopPoll,
     0x56d6a247: types.ChannelAdminLogEventActionToggleGroupCallSetting,
@@ -448,7 +469,7 @@ _all = {
     0xe9e82c18: types.ChannelAdminLogEventActionUpdatePinned,
     0xea107ae4: types.ChannelAdminLogEventsFilter,
     0x289da732: types.ChannelForbidden,
-    0xef3a6acd: types.ChannelFull,
+    0x2548c037: types.ChannelFull,
     0x209b82db: types.ChannelLocation,
     0xbfb5ad8b: types.ChannelLocationEmpty,
     0xcd77d957: types.ChannelMessagesFilter,
@@ -473,14 +494,15 @@ _all = {
     0xf0173fe9: types.channels.ChannelParticipantsNotModified,
     0x3bda1bde: types.Chat,
     0x5fb224d5: types.ChatAdminRights,
+    0xdfd2330f: types.ChatAdminWithInvites,
     0x9f120418: types.ChatBannedRights,
     0x9ba2d800: types.ChatEmpty,
     0x7328bdb: types.ChatForbidden,
-    0xdc8c181: types.ChatFull,
+    0xf06c4018: types.ChatFull,
     0xdfc2f58e: types.ChatInvite,
     0x5a686d7c: types.ChatInviteAlready,
-    0x69df3769: types.ChatInviteEmpty,
-    0xfc2e05bc: types.ChatInviteExported,
+    0x6e24fc9d: types.ChatInviteExported,
+    0x1e3e6680: types.ChatInviteImporter,
     0x61695cb0: types.ChatInvitePeek,
     0xf041e250: types.ChatOnlines,
     0xc8d7493e: types.ChatParticipant,
@@ -529,7 +551,7 @@ _all = {
     0xb3fb5361: types.EmojiLanguage,
     0xa575739d: types.EmojiURL,
     0xfa56ce36: types.EncryptedChat,
-    0x13d6dd27: types.EncryptedChatDiscarded,
+    0x1e1c7c45: types.EncryptedChatDiscarded,
     0xab7ec0a0: types.EncryptedChatEmpty,
     0x62718a82: types.EncryptedChatRequested,
     0x3bf703dc: types.EncryptedChatWaiting,
@@ -548,7 +570,7 @@ _all = {
     0xbea2f424: types.GlobalPrivacySettings,
     0x55903081: types.GroupCall,
     0x7780bcb4: types.GroupCallDiscarded,
-    0x56b087c9: types.GroupCallParticipant,
+    0x64c62a15: types.GroupCallParticipant,
     0x1da7158f: types.help.AppUpdate,
     0x87d0759e: types.help.CountriesList,
     0x93cc1f32: types.help.CountriesListNotModified,
@@ -622,7 +644,7 @@ _all = {
     0xd02e7fd4: types.InputKeyboardButtonUrlAuth,
     0xf8ab7dfb: types.InputMediaContact,
     0xe66fbf7b: types.InputMediaDice,
-    0x23ab23d2: types.InputMediaDocument,
+    0x33473058: types.InputMediaDocument,
     0xfb52dc99: types.InputMediaDocumentExternal,
     0x9664f57f: types.InputMediaEmpty,
     0xd33f43f3: types.InputMediaGame,
@@ -662,8 +684,8 @@ _all = {
     0xb8bc5b0c: types.InputNotifyPeer,
     0x193b4417: types.InputNotifyUsers,
     0x3417d728: types.InputPaymentCredentials,
-    0xca05d50e: types.InputPaymentCredentialsAndroidPay,
     0xaa1c39f: types.InputPaymentCredentialsApplePay,
+    0x8ac32801: types.InputPaymentCredentialsGooglePay,
     0xc10eb2cf: types.InputPaymentCredentialsSaved,
     0x20adaef8: types.InputPeerChannel,
     0x9c95f7bb: types.InputPeerChannelFromMessage,
@@ -698,8 +720,9 @@ _all = {
     0x90110467: types.InputPrivacyValueDisallowUsers,
     0xadf44ee3: types.InputReportReasonChildAbuse,
     0x9b89f93a: types.InputReportReasonCopyright,
+    0xf5ddd6e7: types.InputReportReasonFake,
     0xdbd4feed: types.InputReportReasonGeoIrrelevant,
-    0xe1746d0a: types.InputReportReasonOther,
+    0xc1e4a2b1: types.InputReportReasonOther,
     0x2e59d922: types.InputReportReasonPornography,
     0x58dbcab8: types.InputReportReasonSpam,
     0x1e22c78d: types.InputReportReasonViolence,
@@ -757,7 +780,7 @@ _all = {
     0x2979eeb2: types.LangPackStringDeleted,
     0x6c47ac9f: types.LangPackStringPluralized,
     0xaed6dbb2: types.MaskCoords,
-    0x58ae39c9: types.Message,
+    0xbce383d2: types.Message,
     0xabe9affe: types.MessageActionBotAllowed,
     0x95d2ac92: types.MessageActionChannelCreate,
     0xb055eaee: types.MessageActionChannelMigrateFrom,
@@ -784,7 +807,8 @@ _all = {
     0x4792929b: types.MessageActionScreenshotTaken,
     0xd95c6154: types.MessageActionSecureValuesSent,
     0x1b287353: types.MessageActionSecureValuesSentMe,
-    0x83e5de54: types.MessageEmpty,
+    0xaa1afbfd: types.MessageActionSetMessagesTTL,
+    0x90a6ca84: types.MessageEmpty,
     0x761e6af4: types.MessageEntityBankCard,
     0x20df5d0: types.MessageEntityBlockquote,
     0xbd610bc9: types.MessageEntityBold,
@@ -821,11 +845,12 @@ _all = {
     0xae30253: types.MessageRange,
     0x4128faac: types.MessageReplies,
     0xa6d57763: types.MessageReplyHeader,
-    0x286fa604: types.MessageService,
+    0x2b085862: types.MessageService,
     0xa28e5559: types.MessageUserVote,
     0x36377430: types.MessageUserVoteInputOption,
     0xe8fe0de: types.MessageUserVoteMultiple,
     0x455b853d: types.MessageViews,
+    0xef8d3e6c: types.messages.AffectedFoundMessages,
     0xb45c69d1: types.messages.AffectedHistory,
     0x84d19185: types.messages.AffectedMessages,
     0xedfd405f: types.messages.AllStickers,
@@ -834,7 +859,9 @@ _all = {
     0x36585ea4: types.messages.BotCallbackAnswer,
     0x947ca848: types.messages.BotResults,
     0x64479808: types.messages.ChannelMessages,
+    0xb69b72d7: types.messages.ChatAdminsWithInvites,
     0xe5d7d19c: types.messages.ChatFull,
+    0x81b6b00a: types.messages.ChatInviteImporters,
     0x64ff9fd5: types.messages.Chats,
     0x9cd81144: types.messages.ChatsSlice,
     0x2c221edd: types.messages.DhConfig,
@@ -843,6 +870,9 @@ _all = {
     0xf0e3e596: types.messages.DialogsNotModified,
     0x71e094f3: types.messages.DialogsSlice,
     0xf5dd8f9d: types.messages.DiscussionMessage,
+    0x1871be50: types.messages.ExportedChatInvite,
+    0x222600ef: types.messages.ExportedChatInviteReplaced,
+    0xbdc62dcc: types.messages.ExportedChatInvites,
     0xf37f2f16: types.messages.FavedStickers,
     0x9e8fa6d3: types.messages.FavedStickersNotModified,
     0xb6abc341: types.messages.FeaturedStickers,
@@ -850,6 +880,8 @@ _all = {
     0x5108d648: types.messages.FoundStickerSets,
     0xd54b65d: types.messages.FoundStickerSetsNotModified,
     0x9a3bfd99: types.messages.HighScores,
+    0x1662af0b: types.messages.HistoryImport,
+    0x5e0fb7b9: types.messages.HistoryImportParsed,
     0xa927fec5: types.messages.InactiveChats,
     0x26b5dde6: types.messages.MessageEditData,
     0xb6c4f543: types.messages.MessageViews,
@@ -1034,6 +1066,7 @@ _all = {
     0x628cbc6f: types.SendMessageChooseContactAction,
     0xdd6a8f48: types.SendMessageGamePlayAction,
     0x176f8ba1: types.SendMessageGeoLocationAction,
+    0xdbda9246: types.SendMessageHistoryImportAction,
     0xd52f73f7: types.SendMessageRecordAudioAction,
     0x88f27fbc: types.SendMessageRecordRoundAction,
     0xa187d66f: types.SendMessageRecordVideoAction,
@@ -1105,6 +1138,7 @@ _all = {
     0xe48f964: types.UpdateBotInlineSend,
     0x5d2f3aa9: types.UpdateBotPrecheckoutQuery,
     0xe0cdc940: types.UpdateBotShippingQuery,
+    0x30ec6ebc: types.UpdateBotStopped,
     0x8317c0c3: types.UpdateBotWebhookJSON,
     0x9b9240a6: types.UpdateBotWebhookJSONQuery,
     0xb6d45656: types.UpdateChannel,
@@ -1118,6 +1152,7 @@ _all = {
     0x40771900: types.UpdateChannelWebPage,
     0x1330a196: types.UpdateChat,
     0x54c01850: types.UpdateChatDefaultBannedRights,
+    0x609a6ed4: types.UpdateChatParticipant,
     0xea4b0e5c: types.UpdateChatParticipantAdd,
     0xb6901959: types.UpdateChatParticipantAdmin,
     0x6e5f8c22: types.UpdateChatParticipantDelete,
@@ -1159,6 +1194,7 @@ _all = {
     0x688a30aa: types.UpdateNewStickerSet,
     0xbec268ef: types.UpdateNotifySettings,
     0x246a4b22: types.UpdatePeerBlocked,
+    0xbb9bb9a5: types.UpdatePeerHistoryTTL,
     0xb4afcfb0: types.UpdatePeerLocated,
     0x6a7e7366: types.UpdatePeerSettings,
     0xab0f6b1e: types.UpdatePhoneCall,
@@ -1180,9 +1216,9 @@ _all = {
     0x9375341e: types.UpdateSavedGifs,
     0xebe46819: types.UpdateServiceNotification,
     0x78d4dec1: types.UpdateShort,
-    0x402d5dbb: types.UpdateShortChatMessage,
-    0x2296d2c8: types.UpdateShortMessage,
-    0x11f1331c: types.UpdateShortSentMessage,
+    0x1157b858: types.UpdateShortChatMessage,
+    0xfaeff833: types.UpdateShortMessage,
+    0x9015e101: types.UpdateShortSentMessage,
     0x43ae3dec: types.UpdateStickerSets,
     0xbb2d201: types.UpdateStickerSetsOrder,
     0x8216fba3: types.UpdateTheme,
@@ -1213,7 +1249,7 @@ _all = {
     0x92d33a0e: types.UrlAuthResultRequest,
     0x938458c1: types.User,
     0x200250ba: types.UserEmpty,
-    0xedf17c12: types.UserFull,
+    0x139a9a77: types.UserFull,
     0x69d3ab26: types.UserProfilePhoto,
     0x4f11bae1: types.UserProfilePhotoEmpty,
     0x9d05049: types.UserStatusEmpty,
