@@ -194,23 +194,26 @@ class GetWallPapers(TL):
 
 
 class ReportPeer(TL):
-    ID = 0xae189d5f
+    ID = 0xc5ba3d86
 
-    def __init__(cls, peer: TL, reason: TL):
+    def __init__(cls, peer: TL, reason: TL, message: str):
         cls.peer = peer
         cls.reason = reason
+        cls.message = message
 
     @staticmethod
     def read(data) -> "ReportPeer":
         peer = data.getobj()
         reason = data.getobj()
-        return ReportPeer(peer=peer, reason=reason)
+        message = String.read(data)
+        return ReportPeer(peer=peer, reason=reason, message=message)
 
     def getvalue(cls) -> bytes:
         data = BytesIO()
         data.write(Int.getvalue(cls.ID, False))
         data.write(cls.peer.getvalue())
         data.write(cls.reason.getvalue())
+        data.write(String.getvalue(cls.message))
         return data.getvalue()
 
 
@@ -1466,3 +1469,30 @@ class SetGlobalPrivacySettings(TL):
         data.write(Int.getvalue(cls.ID, False))
         data.write(cls.settings.getvalue())
         return data.getvalue()
+
+
+class ReportProfilePhoto(TL):
+    ID = 0xfa8cc6f5
+
+    def __init__(cls, peer: TL, photo_id: TL, reason: TL, message: str):
+        cls.peer = peer
+        cls.photo_id = photo_id
+        cls.reason = reason
+        cls.message = message
+
+    @staticmethod
+    def read(data) -> "ReportProfilePhoto":
+        peer = data.getobj()
+        photo_id = data.getobj()
+        reason = data.getobj()
+        message = String.read(data)
+        return ReportProfilePhoto(peer=peer, photo_id=photo_id, reason=reason, message=message)
+
+    def getvalue(cls) -> bytes:
+        data = BytesIO()
+        data.write(Int.getvalue(cls.ID, False))
+        data.write(cls.peer.getvalue())
+        data.write(cls.photo_id.getvalue())
+        data.write(cls.reason.getvalue())
+        data.write(String.getvalue(cls.message))
+        return data.getvalue()
