@@ -202,9 +202,10 @@ class GetFullChannel(TL):
 class CreateChannel(TL):
     ID = 0x3d5fb10f
 
-    def __init__(cls, title: str, about: str, broadcast: bool = None, megagroup: bool = None, geo_point: TL = None, address: str = None):
+    def __init__(cls, title: str, about: str, broadcast: bool = None, megagroup: bool = None, for_import: bool = None, geo_point: TL = None, address: str = None):
         cls.broadcast = broadcast
         cls.megagroup = megagroup
+        cls.for_import = for_import
         cls.title = title
         cls.about = about
         cls.geo_point = geo_point
@@ -215,11 +216,12 @@ class CreateChannel(TL):
         flags = Int.read(data)
         broadcast = True if flags & 1 else False
         megagroup = True if flags & 2 else False
+        for_import = True if flags & 8 else False
         title = String.read(data)
         about = String.read(data)
         geo_point = data.getobj() if flags & 4 else None
         address = String.read(data) if flags & 4 else None
-        return CreateChannel(broadcast=broadcast, megagroup=megagroup, title=title, about=about, geo_point=geo_point, address=address)
+        return CreateChannel(broadcast=broadcast, megagroup=megagroup, for_import=for_import, title=title, about=about, geo_point=geo_point, address=address)
 
     def getvalue(cls) -> bytes:
         data = BytesIO()
@@ -227,6 +229,7 @@ class CreateChannel(TL):
         flags = 0
         flags |= 1 if cls.broadcast is not None else 0
         flags |= 2 if cls.megagroup is not None else 0
+        flags |= 8 if cls.for_import is not None else 0
         flags |= 4 if cls.geo_point is not None else 0
         flags |= 4 if cls.address is not None else 0
         data.write(Int.getvalue(flags))
@@ -797,3 +800,21 @@ class GetInactiveChannels(TL):
         data.write(Int.getvalue(cls.ID, False))
         
         return data.getvalue()
+
+
+class ConvertToGigagroup(TL):
+    ID = 0xb290c69
+
+    def __init__(cls, channel: TL):
+        cls.channel = channel
+
+    @staticmethod
+    def read(data) -> "ConvertToGigagroup":
+        channel = data.getobj()
+        return ConvertToGigagroup(channel=channel)
+
+    def getvalue(cls) -> bytes:
+        data = BytesIO()
+        data.write(Int.getvalue(cls.ID, False))
+        data.write(cls.channel.getvalue())
+        return data.getvalue()
