@@ -16,4 +16,4 @@ class TL:
     def getvalue(self) -> bytes:
         ...
 
-    __str__ = __repr__ = lambda self: get_json(self)
+    __str__ = __repr__ = lambda self: get_json(self, as_string=True)
