@@ -1079,3 +1079,192 @@ class DiscussionMessage(TL):
         data.write(Vector().getvalue(cls.chats))
         data.write(Vector().getvalue(cls.users))
         return data.getvalue()
+
+
+class HistoryImport(TL):
+    ID = 0x1662af0b
+
+    def __init__(cls, id: int):
+        cls.id = id
+
+    @staticmethod
+    def read(data) -> "HistoryImport":
+        id = Long.read(data)
+        return HistoryImport(id=id)
+
+    def getvalue(cls) -> bytes:
+        data = BytesIO()
+        data.write(Int.getvalue(cls.ID, False))
+        data.write(Long.getvalue(cls.id))
+        return data.getvalue()
+
+
+class HistoryImportParsed(TL):
+    ID = 0x5e0fb7b9
+
+    def __init__(cls, pm: bool = None, group: bool = None, title: str = None):
+        cls.pm = pm
+        cls.group = group
+        cls.title = title
+
+    @staticmethod
+    def read(data) -> "HistoryImportParsed":
+        flags = Int.read(data)
+        pm = True if flags & 1 else False
+        group = True if flags & 2 else False
+        title = String.read(data) if flags & 4 else None
+        return HistoryImportParsed(pm=pm, group=group, title=title)
+
+    def getvalue(cls) -> bytes:
+        data = BytesIO()
+        data.write(Int.getvalue(cls.ID, False))
+        flags = 0
+        flags |= 1 if cls.pm is not None else 0
+        flags |= 2 if cls.group is not None else 0
+        flags |= 4 if cls.title is not None else 0
+        data.write(Int.getvalue(flags))
+        
+        if cls.title is not None:
+            data.write(String.getvalue(cls.title))
+        return data.getvalue()
+
+
+class AffectedFoundMessages(TL):
+    ID = 0xef8d3e6c
+
+    def __init__(cls, pts: int, pts_count: int, offset: int, messages: List[int]):
+        cls.pts = pts
+        cls.pts_count = pts_count
+        cls.offset = offset
+        cls.messages = messages
+
+    @staticmethod
+    def read(data) -> "AffectedFoundMessages":
+        pts = Int.read(data)
+        pts_count = Int.read(data)
+        offset = Int.read(data)
+        messages = data.getobj(Int)
+        return AffectedFoundMessages(pts=pts, pts_count=pts_count, offset=offset, messages=messages)
+
+    def getvalue(cls) -> bytes:
+        data = BytesIO()
+        data.write(Int.getvalue(cls.ID, False))
+        data.write(Int.getvalue(cls.pts))
+        data.write(Int.getvalue(cls.pts_count))
+        data.write(Int.getvalue(cls.offset))
+        data.write(Vector().getvalue(cls.messages, Int))
+        return data.getvalue()
+
+
+class ExportedChatInvites(TL):
+    ID = 0xbdc62dcc
+
+    def __init__(cls, count: int, invites: List[TL], users: List[TL]):
+        cls.count = count
+        cls.invites = invites
+        cls.users = users
+
+    @staticmethod
+    def read(data) -> "ExportedChatInvites":
+        count = Int.read(data)
+        invites = data.getobj()
+        users = data.getobj()
+        return ExportedChatInvites(count=count, invites=invites, users=users)
+
+    def getvalue(cls) -> bytes:
+        data = BytesIO()
+        data.write(Int.getvalue(cls.ID, False))
+        data.write(Int.getvalue(cls.count))
+        data.write(Vector().getvalue(cls.invites))
+        data.write(Vector().getvalue(cls.users))
+        return data.getvalue()
+
+
+class ExportedChatInvite(TL):
+    ID = 0x1871be50
+
+    def __init__(cls, invite: TL, users: List[TL]):
+        cls.invite = invite
+        cls.users = users
+
+    @staticmethod
+    def read(data) -> "ExportedChatInvite":
+        invite = data.getobj()
+        users = data.getobj()
+        return ExportedChatInvite(invite=invite, users=users)
+
+    def getvalue(cls) -> bytes:
+        data = BytesIO()
+        data.write(Int.getvalue(cls.ID, False))
+        data.write(cls.invite.getvalue())
+        data.write(Vector().getvalue(cls.users))
+        return data.getvalue()
+
+
+class ExportedChatInviteReplaced(TL):
+    ID = 0x222600ef
+
+    def __init__(cls, invite: TL, new_invite: TL, users: List[TL]):
+        cls.invite = invite
+        cls.new_invite = new_invite
+        cls.users = users
+
+    @staticmethod
+    def read(data) -> "ExportedChatInviteReplaced":
+        invite = data.getobj()
+        new_invite = data.getobj()
+        users = data.getobj()
+        return ExportedChatInviteReplaced(invite=invite, new_invite=new_invite, users=users)
+
+    def getvalue(cls) -> bytes:
+        data = BytesIO()
+        data.write(Int.getvalue(cls.ID, False))
+        data.write(cls.invite.getvalue())
+        data.write(cls.new_invite.getvalue())
+        data.write(Vector().getvalue(cls.users))
+        return data.getvalue()
+
+
+class ChatInviteImporters(TL):
+    ID = 0x81b6b00a
+
+    def __init__(cls, count: int, importers: List[TL], users: List[TL]):
+        cls.count = count
+        cls.importers = importers
+        cls.users = users
+
+    @staticmethod
+    def read(data) -> "ChatInviteImporters":
+        count = Int.read(data)
+        importers = data.getobj()
+        users = data.getobj()
+        return ChatInviteImporters(count=count, importers=importers, users=users)
+
+    def getvalue(cls) -> bytes:
+        data = BytesIO()
+        data.write(Int.getvalue(cls.ID, False))
+        data.write(Int.getvalue(cls.count))
+        data.write(Vector().getvalue(cls.importers))
+        data.write(Vector().getvalue(cls.users))
+        return data.getvalue()
+
+
+class ChatAdminsWithInvites(TL):
+    ID = 0xb69b72d7
+
+    def __init__(cls, admins: List[TL], users: List[TL]):
+        cls.admins = admins
+        cls.users = users
+
+    @staticmethod
+    def read(data) -> "ChatAdminsWithInvites":
+        admins = data.getobj()
+        users = data.getobj()
+        return ChatAdminsWithInvites(admins=admins, users=users)
+
+    def getvalue(cls) -> bytes:
+        data = BytesIO()
+        data.write(Int.getvalue(cls.ID, False))
+        data.write(Vector().getvalue(cls.admins))
+        data.write(Vector().getvalue(cls.users))
+        return data.getvalue()
